@@ -16,24 +16,38 @@ from source import calculations
 
 @dataclass
 class Nim(calculations.Mixin):
-    """Class to implement the Nim game
+    """The main class to implement the Nim game
+    
+    This class publishes the following methods. See also the calculation methods from the mixin
+    in :mod:`source.calculations`.
 
-    Methods:
-    - setup_heaps(): initiate the heaps. Note that this creates the heaps
-        instance attribute, i.e. there is no need for __init__()
-    - set_start(): set which party is to start the game
-    - do_move(): do a move, either the Computer's or the Player's turn
-    - get_heapstatus(): get the heap status (coins in heaps)
-    - game_end(): figure out whether the game ended
-    - calculation methods from the mixin
+    **Instance Methods:**
+    
+        :meth:`setup_heaps`
+            This creates and initiates the :attr:`heaps` attribute.
+        
+        :meth:`set_start`
+            It sets which party is to start the game.
+        
+        :meth:`do_move`
+            It makes a move, and swaps the :attr:`activeplayer`.
+        
+        :meth:`get_heapstatus`
+            You can get the :attr:`heaps` status (coins in heaps) in a string.
+        
+        :meth:`game_end`
+            It tells you whether the game has ended.
 
+    
+    **Instance Attributes:**
+    
     Attributes:
-        heaps (list): it contans the number of coins in each heap. This is
-            initiated in setup_heaps().
-        activeplayer (str): either the "Computer" or "Player"; or "start" in the
-            beginning
-        nextturn (iterator.__next__): calling it infinitely yields the swapped
-            player names
+        heaps: This :obj:`list` contans the number of coins in the heaps. This is
+            initiated in :meth:`setup_heaps` and the actual status can be
+            retrieved with :meth:`get_heapstatus`.
+        activeplayer: This :obj:`str` is either the "Computer" or "Player" during
+            the game. Or "start" in the very beginning when starting player
+            has not been selected yet.
 
     Args:
         error_rate: The rate percentage of mistakes the Computer is to make. By
@@ -43,18 +57,19 @@ class Nim(calculations.Mixin):
             Computer would always intentionally make wrong moves, practically
             making all attempts to lose. NB, if the Player does the same, the
             Computer may still win.
-            For testing, when moves of both parties are made by the program,
-            the error rate of both parties can be set with the "ErrorRate"
-            namedtuple. This can be used to create staistics of games played by
-            different skilled players. NB, still, the 1st party will be reported
-            in the results as Computer, and the 2nd as Player, just to name
-            them.
+            
+            For testing, when moves of both parties are calculated by the
+            program, the error rate of both parties can be set with the
+            :obj:`typedefs.ErrorRate`. This can be used to create
+            staistics of games played by differently skilled players. NB, still,
+            the 1\ :sup:`st` party will be reported in the results as Computer,
+            and the 2\ :sup:`nd` as Player, just to name them.
         heapcount_range: The min and max number of heaps to be set up. Less than
             3 heaps makes little sense, more than 15 is a bit of an overkill.
             So, the default is (3-15), but it can be set otherwise. NB, since
             the heaps are displayed with letters (A-Z), the heap number is
             limited to 26.
-        coincount_range: The min and max number of strwas to be set up in a
+        coincount_range: The min and max number of coins to be set up in a
             heap. Less than 1 coin makes no sense, more than 20 is a bit of an
             overkill. So, the default is (1-20). NB, since the heap contents are
             displayed in max 2 digits, the coin number is limited to 99.
@@ -167,14 +182,14 @@ class Nim(calculations.Mixin):
     ) -> None:
         """Initial setup of heaps of coins
         
-        If "heapcounts" is provided the number of heaps and the number of coins
+        If `heapcounts` is provided the number of heaps and the number of coins
         in each heap is checked whether they fall into the set valid range.
         Exception is raised if not.
         
         Args:
-            heapcounts: list elements state the number of coins in each heap.
-                If no list is provided, a random number of heaps are created
-                with random number of coins.
+            heapcounts: The list elements state the number of coins in each
+                heap. If no list is provided, a random number of heaps are
+                created with random number of coins.
         """
         #random heaps to be created?
         if not heapcounts:
@@ -218,7 +233,7 @@ class Nim(calculations.Mixin):
         User can explicitly set which party is to start. This makes sense if
         this decision is made based on the starting heap status.
         
-        The user can also ask for random selection.
+        You can also ask for random selection.
         
         By default the computer makes the decision using 2 factors. First it
         figures out whether the heap status is beneficial for starting. i.e. it
@@ -226,18 +241,25 @@ class Nim(calculations.Mixin):
         intentionally makes a wrong decision with higher likelihood if the
         error_rate is higher.
         
-        Note:
-            The myturn argument is internally converted to a boolean if it
-            arrives as a str. The myturn value is used in a bool context, i.e.
-            it can be any type (e.g. empty list will act like a False, i.e.
-            Computer is to start). No issues with "overwriting" it as the
-            default remains the 'a' for subsequent calls and also the outer
-            variable, where the argument comes from, remains unaffected.
+        The `myturn` argument is converted to a boolean, if it arrives as a
+        :obj:`str`, see the parameter description below. No issues with
+        "overwriting" it, as the default remains the 'a' for subsequent calls
+        and also the outer variable, where the argument comes from, remains
+        unaffected.
+        
+        The (converted) `myturn` value is then used in a :obj:`bool` context.
+        If it is of any other type, it is still interpreted as a bool. E.g. an
+        empty list will act like a False, i.e. Computer will start. 
+        
+        The attribute `nextturn` is an :obj:`iterator.__next_`. Calling it
+        infinitely yields the swapped player names. This attribute is also
+        used in :meth:`do_move`.
         
         Args:
-            myturn: the logical value from the Player's point of view.
+            myturn: The logical value from the Player's point of view.
+            
                 - 'a' (by default): the Computer figures out which party is to start
-                    the game, based on the heap counts and the required error_rate
+                  the game, based on the heap counts and the required error rate
                 - truthy or 'p': Player
                 - falsy or 'c': Computer
                 - 'r': random
@@ -281,8 +303,9 @@ class Nim(calculations.Mixin):
         error_rate: ErrorRate_T
     ) -> None:
         """Set the required error rate, even during a game
-        
-        For the definition of "error_rate", see the class argument. 
+
+        Args:
+            error_rate: The error rate to be set from the next move on 
         """
         #validate the error rate
         v8.validate(
